#
# spec file for package python-readme_renderer
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-readme_renderer
Version:        29.0
Release:        bp153.1.1
Summary:        A library for rendering "readme" descriptions
License:        Apache-2.0
URL:            https://github.com/pypa/readme_renderer
Source:         https://files.pythonhosted.org/packages/source/r/readme_renderer/readme_renderer-%{version}.tar.gz
# PATCH-FIX-UPSTREAM remove-mock.patch -- part of gh#pypa/readme_renderer#192
Patch0:         https://github.com/pypa/readme_renderer/commit/091bcd6.patch#/remove-mock.patch
# PATCH-FIX-UPSTREAM remove-six.patch -- part of gh#pypa/readme_renderer#192
Patch1:         https://github.com/pypa/readme_renderer/commit/690e524.patch#/remove-six.patch
BuildRequires:  %{python_module Pygments >= 2.5.1}
BuildRequires:  %{python_module bleach >= 2.1.0}
BuildRequires:  %{python_module cmarkgfm >= 0.5.0}
BuildRequires:  %{python_module docutils >= 0.13.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments >= 2.5.1
Requires:       python-bleach >= 2.1.0
Requires:       python-docutils >= 0.13.1
Recommends:     python-cmarkgfm >= 0.5.0
BuildArch:      noarch
%python_subpackages

%description
Readme Renderer is a library that will safely render arbitrary ``README`` files
into HTML. It is designed to be used in Warehouse to render the
long_description for packages.

%prep
%autosetup -p1 -n readme_renderer-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%{python_sitelib}/*

%changelog
* Mon Mar 22 2021 Ben Greiner <code@bnavigator.de>
- Update to 29.0
  * Support cmarkgfm>=0.5.0 (#180)
  * Drop support for Python 2 and 3.5 (#188)
- Release 28.0
  * Support Python 3.9 (#176)
- Release 27.0
  * Add support for align attribute rendering Markdown headers
    (#173)
- Add remove-mock.patch and remove-six.patch to reduce outdated
  dependecies -- gh#pypa/readme_renderer#192
* Mon Aug  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 26.0
  * Fix regression with image width/height attributes
* Tue Mar 24 2020 Antonio Larrosa <alarrosa@suse.com>
- Do not build the python2 package since Pygments, which is required
  only builds a python3 package.
* Sun Mar 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 25.0:
  * Fix testsuite to work with new pygments
- Remove merged patch pygments25.patch
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix test fixtures with new pygments:
  * pygments25.patch
* Sun Mar  3 2019 John Vandenberg <jayvdb@gmail.com>
- Remove bcond_with test preventing the tests from running
- Remove unnecessary dependency on flake8
- Increase dependency on bleach to fix test failure
- Add cmarkgfm >= 0.2.0 from upstream
* Sun Dec 30 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 24.0:
  * Remove dependency on ``future``. (#134)
  * Breaking change: Move the cmarkgfm dependency into an extra (#130). Users
    that want to render Markdown will need to install readme_render[md] instead.
  * Unify handling of SVG and other images in RST. (#113)
  * Support width and alignment of images in RST (#114)
  * Allow <caption>. (#105)
  * Add specific tests for the raw directive. (#103)
  * Include docinfo when rendering rst. (#99)
  * Make Python 3 the default lexer for highlighting Python code in Markdown (#97)
  * Allow align attribute on <p> tags (#98)
  * Reformat docutils messages into more human-friendly output. (#92)
  * Fix incorrect escaping of html entities in pre tags when using markdown. (#89)
  * Allow width, height, alt, and align attributes on img tags. (#91)
  * Fix check to not report success when there is invalid RST. (#90)
  * Allow details and summary tags. (#77)
  * Add .pytest_cache to .gitignore. (#85)
  * Warn about Markdown content type when checking RST. (#83)
  * Update pep8 tox env to use py3.6. (#84)
  * Add Pygments-based syntax highlighting for Markdown. (#82)
  * Update docs about check to talk about Markdown. (#80)
  * Change Github-flavored Markdown identifier from ``gfm`` to ``GFM``.
  * Add support for GitHub-flavored Markdown. (#67)
  * Switch to cmarkgfm completely for rendering Markdown. (#68)
  * Warn about missing long description. (#69)
  * Make Github-Flavored Markdown the default variant (#73)
  * All renderers now accept arbitrary ``kwargs`` for future-proofing.
  * Gracefully handle new exceptions from bleach.
  * Fix an issue cleaning plaintext values.
  * Fix an issue attempting to clean data that had ``<a>`` tags without a href.
- Use %%license macro
* Mon Aug 14 2017 toddrme2178@gmail.com
- Initial version
